#
# spec file for package nfs-ganesha
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#
%define __arch_install_post /usr/lib/rpm/check-rpaths /usr/lib/rpm/check-buildroot

%if 0%{?fedora} >= 15 || 0%{?rhel} >= 7
%global with_nfsidmap 1
%else
%global with_nfsidmap 0
%endif

%if 0%{?suse_version}
BuildRequires:  distribution-release
%global with_nfsidmap 1
%endif

# Conditionally enable some FSALs, disable others.
#
# 1. rpmbuild accepts these options (gpfs as example):
#    --with gpfs
#    --without gpfs

%define on_off_switch() %%{?with_%1:ON}%%{!?with_%1:OFF}

# A few explanation about % bcond_with and % bcond_without
# /!\ be careful: this syntax can be quite messy
# % bcond_with means you add a "--with" option, default = without this feature
# % bcond_without adds a"--without" so the feature is enabled by default

%bcond_without nullfs
%global use_fsal_null %{on_off_switch nullfs}

%bcond_with mem
%global use_fsal_mem %{on_off_switch mem}

%bcond_with gpfs
%global use_fsal_gpfs %{on_off_switch gpfs}

%bcond_with xfs
%global use_fsal_xfs %{on_off_switch xfs}

%bcond_with lustre
%global use_fsal_lustre %{on_off_switch lustre}

%bcond_without ceph
%global use_fsal_ceph %{on_off_switch ceph}

%bcond_without rgw
%global use_fsal_rgw %{on_off_switch rgw}

%bcond_with gluster
%global use_fsal_gluster %{on_off_switch gluster}

%bcond_with panfs
%global use_fsal_panfs %{on_off_switch panfs}

%bcond_with rdma
%global use_rdma %{on_off_switch rdma}

%bcond_with jemalloc

%bcond_with lttng
%global use_lttng %{on_off_switch lttng}

%bcond_with utils
%global use_utils %{on_off_switch utils}

%bcond_with gui_utils
%global use_gui_utils %{on_off_switch gui_utils}

%bcond_with system_ntirpc
%global use_system_ntirpc %{on_off_switch system_ntirpc}

%bcond_without man_page
%global use_man_page %{on_off_switch man_page}

%bcond_without rados_recov
%global use_rados_recov %{on_off_switch rados_recov}

%bcond_without rados_urls
%global use_rados_urls %{on_off_switch rados_urls}

%bcond_without rpcbind
%global use_rpcbind %{on_off_switch rpcbind}

%bcond_with mspac_support
%global use_mspac_support %{on_off_switch mspac_support}

%bcond_with sanitize_address
%global use_sanitize_address %{on_off_switch sanitize_address}

%global dev_version %{lua: s = string.gsub('@GANESHA_EXTRA_VERSION@', '^%-', ''); s2 = string.gsub(s, '%-', '.'); print((s2 ~= nil and s2 ~= '') and s2 or "0.1") }

%define sourcename @CPACK_SOURCE_PACKAGE_FILE_NAME@

Name:           nfs-ganesha
Version:        3.3+git0.39e0cf712
Release:        5.10
Summary:        An NFS server running in user space
License:        GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          Productivity/Networking/NFS
URL:            https://github.com/nfs-ganesha/nfs-ganesha/wiki

Source:         %{name}-%{version}.tar.bz2
Patch0:         fix-compilation--faulty-version-comparison.patch
Patch1:         getopt_aarch64.patch

%if 0%{?suse_version}
%if 0%{?is_opensuse}
ExclusiveArch:  x86_64 aarch64 ppc64 ppc64le
%else
ExclusiveArch:  x86_64 aarch64
%endif
%endif

BuildRequires:  bison
BuildRequires:  cmake
BuildRequires:  flex
BuildRequires:  flex
BuildRequires:  krb5-devel
BuildRequires:  liburcu-devel
BuildRequires:  pkgconfig
%if %{with rados_recov} || %{with rados_urls}
BuildRequires:  librados-devel >= 0.61
%endif
%if ( 0%{?suse_version} >= 1330 )
BuildRequires:  libnsl-devel
%endif
%if ( 0%{?suse_version} )
BuildRequires:  dbus-1-devel
Requires:       dbus-1
%else
BuildRequires:  dbus-devel
Requires:       dbus
%endif

BuildRequires:  libblkid-devel
BuildRequires:  libcap-devel
BuildRequires:  libuuid-devel
%if %{with mspac_support}
BuildRequires:  libwbclient-devel
%endif
BuildRequires:  gcc-c++
%if %{with system_ntirpc}
BuildRequires:  libntirpc-devel >= 1.3.1
%endif
%if %{with sanitize_address}
BuildRequires:  libasan
%endif
Requires:       nfs-utils

%if ( 0%{?with_rpcbind} )
%if ( 0%{?fedora} ) || ( 0%{?rhel} && 0%{?rhel} >= 6 ) || ( 0%{?suse_version} )
Requires:       rpcbind
%else
Requires:       portmap
%endif
%endif

%if %{with_nfsidmap}
%if ( 0%{?suse_version} )
BuildRequires:  nfsidmap-devel
%else
BuildRequires:  libnfsidmap-devel
%endif
%else
BuildRequires:  nfs-utils-lib-devel
%endif

%if %{with rdma}
BuildRequires:  libmooshika-devel >= 0.6-0
%endif
%if %{with jemalloc}
BuildRequires:  jemalloc-devel
%endif
%if 0%{?suse_version}
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(systemd)
%{?systemd_ordering}
PreReq:         %fillup_prereq
Requires(post): procps
%else
Requires(post): systemd
Requires(preun):systemd
Requires(postun):systemd
BuildRequires:  systemd
%endif

%if %{with man_page}
BuildRequires:  python3-Sphinx
%endif

# Use CMake variables

%description
NFS-Ganesha is an NFS server running in userspace. It comes with various
back-end modules (called File System Abstraction Layers - FSALs) for different
file systems and name-spaces (notably the Ceph "file" and "object" back-ends -
CephFS and RGW, respectively).

%package -n libntirpc3_3
Summary:        NFS-Ganesha transport-independent RPC (TI-RPC) shared library
Group:          System/Libraries

%description -n libntirpc3_3
This package contains a new implementation of the original libtirpc,
transport-independent RPC (TI-RPC) library for NFS-Ganesha. It has
the following features not found in libtirpc:
 1. Bi-directional operation
 2. Full-duplex operation on the TCP (vc) transport
 3. Thread-safe operating modes
 3.1 new locking primitives and lock callouts (interface change)
 3.2 stateless send/recv on the TCP transport (interface change)
 4. Flexible server integration support
 5. Event channels (remove static arrays of xprt handles, new EPOLL/KEVENT
    integration)

%post -n libntirpc3_3 -p /sbin/ldconfig

%postun -n libntirpc3_3 -p /sbin/ldconfig

%package -n libntirpc-devel
Summary:        Copy of TIRPC headers from NFS-Ganesha
Group:          Development/Libraries/C and C++
Requires:       libntirpc3_3 = %{version}
Obsoletes:      nfs-ganesha-devel < %{version}

%description -n libntirpc-devel
This package contains the libraries and headers needed to develop programs
using NFS-Ganesha transport-independent RPC (TI-RPC).

%package -n libganesha_nfsd3_3
Summary:        NFS-Ganesha NFSD shared library
Group:          System/Libraries

%description -n libganesha_nfsd3_3
This package contains the NFSD shared library from NFS-Ganesha.

%post -n libganesha_nfsd3_3 -p /sbin/ldconfig

%postun -n libganesha_nfsd3_3 -p /sbin/ldconfig

%package -n libganesha_nfsd-devel
Summary:        NFS-Ganesha NFSD shared library
Group:          Development/Libraries/C and C++
Requires:       libganesha_nfsd3_3 = %{version}

%description -n libganesha_nfsd-devel
This package contains the libraries and headers needed to develop programs
using NFS-Ganesha NFSD.

%package mount-9P
Summary:        a 9p mount helper
Group:          System/Filesystems

%description mount-9P
This package contains the mount.9P script that clients can use
to simplify mounting to NFS-Ganesha. This is a 9p mount helper.

%package vfs
Summary:        VFS backend for NFS-Ganesha
Group:          Productivity/Networking/NFS
BuildRequires:  libattr-devel
Requires:       nfs-ganesha = %{version}-%release

%description vfs
This package contains a FSAL shared object to
be used with NFS-Ganesha to support VFS based filesystems

%package proxy
Summary:        PROXY-based filesystem backend for NFS-GANESHA
Group:          Productivity/Networking/NFS
BuildRequires:  libattr-devel
Requires:       nfs-ganesha = %{version}-%{release}

%description proxy
This package contains a FSAL shared object to
be used with NFS-Ganesha to support PROXY based filesystems

%if %{with utils}
%package utils
Summary:        The NFS-Ganesha utility scripts
Group:          Productivity/Networking/NFS
%if ( 0%{?rhel} && 0%{?rhel} < 8 )
Requires:       dbus-python
Requires:       pygobject2
Requires:       pyparsing
BuildRequires:  python-devel
%else
Requires:       python3-gobject
Requires:       python3-pyparsing
BuildRequires:  python3-devel
%endif
%if ( 0%{?suse_version} )
Requires:       dbus-1-python
%else
Requires:       python3-dbus
%endif
%if %{with gui_utils}
%if ( 0%{?suse_version} )
BuildRequires:  python3-qt5-devel
Requires:       python3-qt5
%else
BuildRequires:  PyQt4-devel
Requires:       PyQt4
%endif
%endif
BuildRequires:  python3-devel
Requires:       nfs-ganesha = %{version}-%{release}
Requires:       python3

%description utils
This package contains utility scripts for managing the NFS-Ganesha server
%endif

%if %{with lttng}
%package lttng
Summary:        The NFS-Ganesha library for use with LTTng
Group:          Productivity/Networking/NFS
BuildRequires:  lttng-tools-devel >= 2.3
BuildRequires:  lttng-ust-devel >= 2.3
Requires:       lttng-tools >= 2.3
Requires:       lttng-ust >= 2.3
Requires:       nfs-ganesha = %{version}-%{release}

%description lttng
This package contains the libganesha_trace.so library. When preloaded
to the ganesha.nfsd server, it makes it possible to trace using LTTng.
%endif

%if %{with rados_recov}
%package rados-grace
Summary:        The NFS-Ganesha command for managing the RADOS grace database
Group:          Productivity/Networking/NFS
BuildRequires:  librados-devel >= 0.61
Requires:       nfs-ganesha = %{version}-%{release}

%description rados-grace
This package contains the ganesha-rados-grace tool for interacting with the
database used by the rados_cluster recovery backend and the
libganesha_rados_grace shared library for using RADOS storage for
recovery state.
%endif

%if %{with rados_urls}
%package rados-urls
Summary:        The NFS-GANESHA library for use with RADOS URLs
Group:          Applications/System
Requires:       nfs-ganesha = %{version}-%{release}

%description rados-urls
This package contains the libganesha_rados_urls library used for
handling RADOS URL configurations.
%endif

# Option packages start here. use "rpmbuild --with gpfs" (or equivalent)
# for activating this part of the spec file

# NULL
%if %{with nullfs}
%package nullfs
Summary:        "null" filesystem backend for NFS-Ganesha
Group:          Productivity/Networking/NFS
Requires:       nfs-ganesha = %{version}-%{release}

%description nullfs
This package contains a Stackable FSAL shared object to
be used with NFS-Ganesha. This is mostly a template for future (more sophisticated) stackable FSALs
%endif

# MEM
%if %{with mem}
%package mem
Summary:        Memory-backed testing filesystem backend for NFS-Ganesha
Group:          Productivity/Networking/NFS
Requires:       nfs-ganesha = %{version}-%{release}

%description mem
This package contains a FSAL shared object to be used with NFS-Ganesha.  This
is used for speed and latency testing.
%endif

# GPFS
%if %{with gpfs}
%package gpfs
Summary:        GPFS backend for NFS-Ganesha
Group:          Productivity/Networking/NFS
Requires:       nfs-ganesha = %{version}-%{release}

%description gpfs
This package contains a FSAL shared object to
be used with NFS-Ganesha to support GPFS backend
%endif

# CEPH
%if %{with ceph}
%package ceph
Summary:        CephFS backend for NFS-Ganesha
Group:          Productivity/Networking/NFS
Requires:       ceph-common
Requires:       nfs-ganesha = %{version}-%{release}
BuildRequires:  libcephfs-devel >= 10.2.0

%description ceph
This package contains the Ceph "file" (CephFS) File System Abstraction Layer
(FSAL).
%endif

# RGW
%if %{with rgw}
%package rgw
Summary:        Ceph RADOS Gateway backend for NFS-Ganesha
Group:          Productivity/Networking/NFS
Requires:       ceph-common
Requires:       nfs-ganesha = %{version}-%{release}
BuildRequires:  librgw-devel >= 10.2.0

%description rgw
This package contains the Ceph "object" (RGW) File System Abstraction Layer
(FSAL).
%endif

# XFS
%if %{with xfs}
%package xfs
Summary:        XFS backend for NFS-Ganesha
Group:          Productivity/Networking/NFS
Requires:       nfs-ganesha = %{version}-%{release}
BuildRequires:  libattr-devel
BuildRequires:  xfsprogs-devel

%description xfs
This package contains the XFS File System Abstraction Layer (FSAL)
for use with NFS-Ganesha, providing correct XFS support.
%endif

#LUSTRE
%if %{with lustre}
%package lustre
Summary:        Lustre backend for NFS-Ganesha
Group:          Productivity/Networking/NFS
BuildRequires:  libattr-devel
BuildRequires:  lustre-client
Requires:       lustre-client
Requires:       nfs-ganesha = %{version}-%{release}

%description lustre
This package contains a FSAL shared object to
be used with NFS-Ganesha to support LUSTRE based filesystems
%endif

# PANFS
%if %{with panfs}
%package panfs
Summary:        PANFS backend for NFS-Ganesha
Group:          Productivity/Networking/NFS
Requires:       nfs-ganesha = %{version}-%{release}

%description panfs
This package contains a FSAL shared object to
be used with NFS-Ganesha to support PANFS
%endif

# GLUSTER
%if %{with gluster}
%package gluster
Summary:        Gluster filesystem backend for NFS-Ganesha
Group:          Productivity/Networking/NFS
Requires:       nfs-ganesha = %{version}-%{release}
BuildRequires:  glusterfs-api-devel >= 3.8
BuildRequires:  libacl-devel
BuildRequires:  libattr-devel

%description gluster
This package contains a FSAL shared object to
be used with NFS-Ganesha to support Gluster
%endif

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
export LANGUAGE=en_US.UTF-8
export LC_ALL=en_US.UTF-8
export LANG=en_US.UTF-8
export LC_TYPE=en_US.UTF-8
%cmake							\
	-DBUILD_CONFIG=rpmbuild				\
	-DUSE_FSAL_NULL=%{use_fsal_null}		\
	-DUSE_FSAL_MEM=%{use_fsal_mem}			\
	-DUSE_FSAL_XFS=%{use_fsal_xfs}			\
	-DUSE_FSAL_LUSTRE=%{use_fsal_lustre}		\
	-DUSE_FSAL_CEPH=%{use_fsal_ceph}		\
	-DUSE_FSAL_RGW=%{use_fsal_rgw}			\
	-DUSE_FSAL_GPFS=%{use_fsal_gpfs}		\
	-DUSE_FSAL_PANFS=%{use_fsal_panfs}		\
	-DUSE_FSAL_GLUSTER=%{use_fsal_gluster}		\
	-DUSE_SYSTEM_NTIRPC=%{use_system_ntirpc}	\
	-DUSE_9P_RDMA=%{use_rdma}			\
	-DUSE_LTTNG=%{use_lttng}			\
	-DUSE_ADMIN_TOOLS=%{use_utils}			\
	-DUSE_GUI_ADMIN_TOOLS=%{use_gui_utils}		\
	-DUSE_RADOS_RECOV=%{use_rados_recov}		\
	-DRADOS_URLS=%{use_rados_urls}			\
	-DUSE_FSAL_VFS=ON				\
	-DUSE_FSAL_PROXY=ON				\
	-DUSE_DBUS=ON					\
	-DUSE_9P=ON					\
	-DDISTNAME_HAS_GIT_DATA=OFF			\
	-DUSE_MAN_PAGE=%{use_man_page}                  \
	-DRPCBIND=%{use_rpcbind}			\
	-D_MSPAC_SUPPORT=%{use_mspac_support}		\
	-DSANITIZE_ADDRESS=%{use_sanitize_address}	\
%if %{with jemalloc}
	-DALLOCATOR=jemalloc
%endif

%cmake_build

%install
mkdir -p %{buildroot}%{_sysconfdir}/ganesha/
mkdir -p %{buildroot}%{_sysconfdir}/dbus-1/system.d
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_libdir}/ganesha
mkdir -p %{buildroot}%{_localstatedir}/run/ganesha
mkdir -p %{buildroot}%{_libexecdir}/ganesha
mkdir -p %{buildroot}%{_docdir}/ganesha
mkdir -p %{buildroot}%{_docdir}/ganesha/config_samples
install -m 644 LICENSE.txt %{buildroot}%{_docdir}/ganesha/LICENSE.txt
install -m 644 config_samples/logrotate_ganesha	%{buildroot}%{_sysconfdir}/logrotate.d/ganesha
install -m 644 scripts/ganeshactl/org.ganesha.nfsd.conf	%{buildroot}%{_sysconfdir}/dbus-1/system.d
install -m 755 scripts/nfs-ganesha-config.sh %{buildroot}%{_libexecdir}/ganesha
install -m 755 tools/mount.9P	%{buildroot}%{_sbindir}/mount.9P

install -m 644 config_samples/vfs.conf %{buildroot}%{_sysconfdir}/ganesha

install -D -m 444 scripts/systemd/nfs-ganesha.service.el7 %{buildroot}%{_unitdir}/nfs-ganesha.service
install -D -m 444 scripts/systemd/nfs-ganesha-lock.service.el7 %{buildroot}%{_unitdir}/nfs-ganesha-lock.service
install -D -m 444 scripts/systemd/nfs-ganesha-config.service %{buildroot}%{_unitdir}/nfs-ganesha-config.service
%if 0%{?suse_version}
install -D -m 644 scripts/systemd/sysconfig/nfs-ganesha %{buildroot}%{_fillupdir}/sysconfig.ganesha
%else
install -D -m 644 scripts/systemd/sysconfig/nfs-ganesha %{buildroot}%{_sysconfdir}/sysconfig/ganesha
%endif
mkdir -p %{buildroot}%{_localstatedir}/log/ganesha

%if %{with xfs}
install -m 644 config_samples/xfs.conf %{buildroot}%{_sysconfdir}/ganesha
%endif

%if %{with ceph}
install -m 644 config_samples/ceph.conf %{buildroot}%{_sysconfdir}/ganesha
%endif

%if %{with rgw}
install -m 644 config_samples/rgw.conf %{buildroot}%{_sysconfdir}/ganesha
install -m 644 config_samples/rgw_bucket.conf %{buildroot}%{_sysconfdir}/ganesha
%endif

%if %{with gpfs}
install -m 755 scripts/gpfs-epoch %{buildroot}%{_libexecdir}/ganesha
install -m 644 config_samples/gpfs.conf	%{buildroot}%{_sysconfdir}/ganesha
install -m 644 config_samples/gpfs.ganesha.nfsd.conf %{buildroot}%{_sysconfdir}/ganesha
install -m 644 config_samples/gpfs.ganesha.main.conf %{buildroot}%{_sysconfdir}/ganesha
install -m 644 config_samples/gpfs.ganesha.log.conf %{buildroot}%{_sysconfdir}/ganesha
install -m 644 config_samples/gpfs.ganesha.exports.conf	%{buildroot}%{_sysconfdir}/ganesha
mkdir -p %{buildroot}%{_sysconfdir}/init.d
install -m 755 scripts/init.d/nfs-ganesha.gpfs		%{buildroot}%{_sysconfdir}/init.d/nfs-ganesha-gpfs
%endif

%cmake_install

%if ( 0%{?suse_version} )
%pre
%service_add_pre nfs-ganesha.service nfs-ganesha-lock.service nfs-ganesha-config.service
getent group ganesha > /dev/null || groupadd -r ganesha
getent passwd ganesha > /dev/null || useradd -r -g ganesha -d /var/run/ganesha -s /sbin/nologin -c "NFS-Ganesha Daemon" ganesha
exit 0

%endif

%post
%if ( 0%{?suse_version} )
%service_add_post nfs-ganesha.service nfs-ganesha-lock.service nfs-ganesha-config.service
%fillup_only -n ganesha
%else
%systemd_post nfs-ganesha-lock.service
%endif
pgrep dbus-daemon >/dev/null 2>&1 && killall -SIGHUP dbus-daemon >/dev/null 2>&1 || :

%preun
%if ( 0%{?suse_version} )
%service_del_preun nfs-ganesha-lock.service
%else
%systemd_preun nfs-ganesha-lock.service
%endif

%postun
%if ( 0%{?suse_version} )
%service_del_postun nfs-ganesha-lock.service
%else
%systemd_postun_with_restart nfs-ganesha-lock.service
%endif

%files
%docdir %{_docdir}/ganesha
%{_bindir}/ganesha.nfsd
%dir %{_libdir}/ganesha
%config %{_sysconfdir}/dbus-1/system.d/org.ganesha.nfsd.conf
%if 0%{?suse_version}
%{_fillupdir}/sysconfig.*
%else
%config(noreplace) %{_sysconfdir}/sysconfig/ganesha
%endif
%config(noreplace) %{_sysconfdir}/logrotate.d/ganesha
%dir %{_sysconfdir}/ganesha
%config(noreplace) %{_sysconfdir}/ganesha/ganesha.conf
%dir %{_docdir}/ganesha
%{_docdir}/ganesha/LICENSE.txt
%dir %{_docdir}/ganesha/config_samples
%{_docdir}/ganesha/config_samples/README
%{_docdir}/ganesha/config_samples/ceph.conf
%{_docdir}/ganesha/config_samples/config.txt
%{_docdir}/ganesha/config_samples/ds.conf
%{_docdir}/ganesha/config_samples/export.txt
%{_docdir}/ganesha/config_samples/ganesha.conf.example
%{_docdir}/ganesha/config_samples/gluster.conf
%{_docdir}/ganesha/config_samples/gpfs.conf
%{_docdir}/ganesha/config_samples/gpfs.ganesha.exports.conf
%{_docdir}/ganesha/config_samples/gpfs.ganesha.log.conf
%{_docdir}/ganesha/config_samples/gpfs.ganesha.main.conf
%{_docdir}/ganesha/config_samples/gpfs.ganesha.nfsd.conf
%{_docdir}/ganesha/config_samples/logging.txt
%{_docdir}/ganesha/config_samples/logrotate_fsal_gluster
%{_docdir}/ganesha/config_samples/logrotate_ganesha
%{_docdir}/ganesha/config_samples/lustre.conf
%{_docdir}/ganesha/config_samples/mem.conf
%{_docdir}/ganesha/config_samples/proxy.conf
%{_docdir}/ganesha/config_samples/rgw.conf
%{_docdir}/ganesha/config_samples/rgw_bucket.conf
%{_docdir}/ganesha/config_samples/vfs.conf
%{_docdir}/ganesha/config_samples/xfs.conf
%dir %{_libexecdir}/ganesha
%{_libexecdir}/ganesha/nfs-ganesha-config.sh
%dir %attr(0755,ganesha,ganesha) %{_localstatedir}/log/ganesha

%if %{with man_page}
%{_mandir}/*/ganesha-config.8.gz
%{_mandir}/*/ganesha-core-config.8.gz
%{_mandir}/*/ganesha-export-config.8.gz
%{_mandir}/*/ganesha-cache-config.8.gz
%{_mandir}/*/ganesha-log-config.8.gz
%endif

%{_unitdir}/nfs-ganesha.service
%{_unitdir}/nfs-ganesha-lock.service
%{_unitdir}/nfs-ganesha-config.service

%if ! %{with system_ntirpc}

%files -n libntirpc3_3
%{_libdir}/libntirpc.so.3.3

%files -n libntirpc-devel
%{_includedir}/ntirpc/
%{_libdir}/libntirpc.so
%{_libdir}/pkgconfig/libntirpc.pc

%endif

%files -n libganesha_nfsd3_3
%{_libdir}/libganesha_nfsd.so.*

%files -n libganesha_nfsd-devel
%{_libdir}/libganesha_nfsd.so

%files mount-9P
%{_sbindir}/mount.9P
%if %{with man_page}
%{_mandir}/*/ganesha-9p-config.8.gz
%endif

%files vfs
%{_libdir}/ganesha/libfsalvfs*
%config(noreplace) %{_sysconfdir}/ganesha/vfs.conf
%if %{with man_page}
%{_mandir}/*/ganesha-vfs-config.8.gz
%endif

%files proxy
%{_libdir}/ganesha/libfsalproxy*
%if %{with man_page}
%{_mandir}/*/ganesha-proxy-config.8.gz
%endif

# Optional packages
%if %{with lustre}
%files lustre
%{_libdir}/ganesha/libfsallustre*
%config(noreplace) %{_sysconfdir}/ganesha/lustre.conf
%if %{with man_page}
%{_mandir}/*/ganesha-lustre-config.8.gz
%endif
%endif

%if %{with nullfs}
%files nullfs
%{_libdir}/ganesha/libfsalnull*
%endif

%if %{with mem}
%files mem
%{_libdir}/ganesha/libfsalmem*
%endif

%if %{with gpfs}
%files gpfs
%{_libdir}/ganesha/libfsalgpfs*
%config(noreplace) %{_sysconfdir}/ganesha/gpfs.conf
%config(noreplace) %{_sysconfdir}/ganesha/gpfs.ganesha.nfsd.conf
%config(noreplace) %{_sysconfdir}/ganesha/gpfs.ganesha.main.conf
%config(noreplace) %{_sysconfdir}/ganesha/gpfs.ganesha.log.conf
%config(noreplace) %{_sysconfdir}/ganesha/gpfs.ganesha.exports.conf
%{_libexecdir}/ganesha/gpfs-epoch
%if %{with man_page}
%{_mandir}/*/ganesha-gpfs-config.8.gz
%endif
%endif

%if %{with xfs}
%files xfs
%{_libdir}/ganesha/libfsalxfs*
%config(noreplace) %{_sysconfdir}/ganesha/xfs.conf
%if %{with man_page}
%{_mandir}/*/ganesha-xfs-config.8.gz
%endif
%endif

%if %{with ceph}
%files ceph
%{_libdir}/ganesha/libfsalceph*
%config(noreplace) %{_sysconfdir}/ganesha/ceph.conf
%if %{with man_page}
%{_mandir}/*/ganesha-ceph-config.8.gz
%endif
%endif

%if %{with rgw}
%files rgw
%{_libdir}/ganesha/libfsalrgw*
%config(noreplace) %{_sysconfdir}/ganesha/rgw.conf
%config(noreplace) %{_sysconfdir}/ganesha/rgw_bucket.conf
%if %{with man_page}
%{_mandir}/*/ganesha-rgw-config.8.gz
%endif
%endif

%if %{with gluster}
%files gluster
%{_libdir}/ganesha/libfsalgluster*
%if %{with man_page}
%{_mandir}/*/ganesha-gluster-config.8.gz
%endif
%endif

%if %{with panfs}
%files panfs
%{_libdir}/ganesha/libfsalpanfs*
%endif

%if %{with lttng}
%files lttng
%{_libdir}/ganesha/libganesha_trace*
%endif

%if %{with rados_recov}
%files rados-grace
%{_bindir}/ganesha-rados-grace
%{_libdir}/libganesha_rados_recov.so*
%if %{with man_page}
%{_mandir}/*/ganesha-rados-grace.8.gz
%{_mandir}/*/ganesha-rados-cluster-design.8.gz
%endif
%endif

%if %{with rados_urls}
%files rados-urls
%{_libdir}/libganesha_rados_urls.so*
%endif

%if %{with utils}
%files utils
%if ( 0%{?suse_version} || 0%{?fedora} )
%{python_sitelib}/Ganesha
%{python_sitelib}/Ganesha/*
%{python_sitelib}/ganeshactl-*-info
%else
%{python2_sitelib}/Ganesha
%{python2_sitelib}/Ganesha/*
%{python2_sitelib}/ganeshactl-*-info
%endif
%if %{with gui_utils}
%{_bindir}/ganesha-admin
%{_bindir}/manage_clients
%{_bindir}/manage_exports
%{_bindir}/manage_logger
%{_bindir}/ganeshactl
%{_bindir}/client_stats_9pOps
%{_bindir}/export_stats_9pOps
%endif
%{_bindir}/fake_recall
%{_bindir}/get_clientids
%{_bindir}/grace_period
%{_bindir}/ganesha_stats
%{_bindir}/sm_notify.ganesha
%{_bindir}/ganesha_mgr
%{_bindir}/ganesha_conf
%{_mandir}/man8/ganesha_conf.8.gz
%endif

%changelog
* Thu Nov 11 2021 Michael Fritch <michael.fritch@suse.com>
- Add patch to fix getopt return value on aarch64 (bsc#1192367)
  * Add getopt_aarch64.patch
- Disable build of the XFS FSAL
  + https://github.com/nfs-ganesha/nfs-ganesha/issues/533
* Fri Jul 23 2021 Patrick Seidensal <pseidensal@suse.com>
- Enable FSAL_RGW again, as it turned out to be compatible with Ceph 16.x, but
  needs patching from upstream. Backport upstream patch to fix version
  comparison.
  * Add fix-compilation--faulty-version-comparison.patch
* Fri Feb  5 2021 Nathan Cutler <ncutler@suse.com>
- Disable FSAL_RGW which is incompatible with Ceph 16.1.0
* Mon Jul 27 2020 Supriti Singh <supriti.singh@suse.com>
- Remove -fcommon from spec file
  * Reverting changes made to fix boo#1164548.
* Fri Jul 17 2020 Supriti Singh <supriti.singh@suse.com>
- dropped fix-compilation-errors-on-xfs-ioctl-syscall-structs.patch which is a part of upstream 3.3
- Update to version 3.3+git0.39e0cf712:
  * V3.3
  * FSAL_CEPH: Fix size of handle
  * FSAL_CEPH: Always use the large handle size
  * FSAL_CEPH: clarify the User_Id setting in the sample config
  * FSAL_CEPH: set ino_release_cb on mount
  * RADOS_URLS: restore rados_urls watch on new configuration
  * RADOS_URLS: when built with rados_urls, don't error if lib not installed
  * Fix accessing object handle after feering its last state
  * Fix get_state_obj_export_owner_refs() fail case
  * Fix responding with NFS version mismatch
  * core: multiple definitions of 'common' data compiling with gcc-10
  * Fixes in stats module
  * Throttle the health warning
  * Fix seg fault when NFSv4 compound op fails for regular files
* Tue Mar 31 2020 Martin Liška <mliska@suse.cz>
- Add -fcommon in order to fix boo#1164548.
* Thu Feb 20 2020 Anthony Iliopoulos <ailiopoulos@suse.com>
- Backported patch that fixes compilation errors with xfsprogs >= v5.3.0
  * added fix-compilation-errors-on-xfs-ioctl-syscall-structs.patch
* Wed Jan 15 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Rename systemd cofig file for nfs-ganesha service to support
  upstream service configuration script
* Wed Jan 15 2020 dkondratenko@suse.com
- Update to version 3.2+git0.8d07e25a7:
  * V3.2
  * Move async callback to svc_req and give it its own wpe
  * Crash under duplicate request "being processed"
  * nfs3_FhandleToExportId returns an int (not a short)
  * Stats for all ops by a client
- Update spec to support 3.2 and remove Obsoletes
* Fri Jan  3 2020 David Disseldorp <ddiss@suse.com>
- Drop -DCMAKE_BUILD_TYPE=Release in favour of %%cmake macro default.
* Fri Jan  3 2020 Martin Liška <mliska@suse.cz>
- Use %%cmake macros for build in order to respect $optflags.
* Thu Dec 19 2019 dkondratenko@suse.com
- Update to version 3.1+git0.4de09d665:
  * V3.1
  * Pullup ntirpc to 3.1
* Mon Dec  9 2019 dkondratenko@suse.com
- Update to version 3.0.3+git0.0c2a4da66:
  * V3.0.3
  * NFS uio setup calloc size incorrect
  * cmake: Add support for Open Build Server
    + remove sle_build_detect.patch as changes upstreamed
  * RADOS - Log a message when requested backend isn't available
  * Handle RPCSEC_GSS negotiation or wrong cred messages
  * Protocol: add config option to force utf8 string scan
  * Clean up UTF-8 checking in preparation for config option
* Fri Nov 29 2019 dkondratenko@suse.com
- Update to version V3.0.2+git0.eae6d6d35:
  * V3.0.2
  * ganesha_stats option rename
  * cmake: LizardFS doesn't need to be a STRICT_PACKAGE
  * Add fsal_test_access to exported symbols.
  * doc: utf8 characters in ganesha-config.rsh
  * V3.0.1
  * Adding trace in FSAL_GLUSTER
  * call set_current_entry only after checking state_lock
  * avoid mem leak
  * Avoid twice free.
* Thu Nov 28 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Changing service file to build from upstream git
- Adding patch to correctly detect SLE during the build
  * added sle_build_detect.patch
- removing add-missing-CheckSymbolExists-include.patch
  * already in sources
* Wed Nov 13 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Update nfs-ganesha to V3.0
  + libntirpc
  + Use non-blocking writes when we send RPC responses or make RPC callbacks
  + Continued improvements of readdir cache
  + Use of gss_iov for GSS integrity and privacy encode and decode to save
    buffer copies.
  + Change xdr encode of attributes to work from struct attrlist and other
    changes to save a data copy when returning attributes for NFS v3.
  + Implement xdr_putbuffs to save buffer copies for READ and READDIR responses
    which also has the benefit of more completely filling the maximum READDIR
    response size for fewer READDIR roundtrips to read a large directory.
  + Add LizardFS FSAL
  + Completed audit of string buffer handling (strncpy, snprintf and such) to
    prevent overflows. Also make utf8str always NUL terminated including on
    XDR decode.
  + Make python scripts compatible with Python 3
  + Python script enhancements and cleanup
  + Enhancements to stats collection
  + Numerous Coverity issues fixed as well as other bug fixes
- remove CMake patch, as it is already in V3.0
* Tue Aug  6 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with CMake 3.15.1, https://github.com/nfs-ganesha/nfs-ganesha/issues/454
  + add-missing-CheckSymbolExists-include.patch
* Mon May 13 2019 Nathan Cutler <ncutler@suse.com>
- Version 2.8.dev.29+git.1557746732.251ace12d:
  + FSAL_CEPH: fix length calculation in reclaim_reset (bsc#1134302)
* Thu May  9 2019 Nathan Cutler <ncutler@suse.com>
- Version 2.8.dev.29+git.1557398426.e91b5c34d:
  + FSAL_CEPH: use a unique uuid string per export (bsc#1134302)
  + Note to reviewer: compared to 2.8.dev.16, this version drops
    the "nfs-ganesha-devel" subpackage (replaced by libntirpc-devel)
* Tue Apr  9 2019 Jan Engelhardt <jengelh@inai.de>
- spec:
  + Reduce scriptlets' hard dependency on systemd
  + Add missing Requires from devel->library
* Tue Apr  9 2019 ncutler@suse.com
- spec: split off NTIRPC and NFSD shared libraries into subpackages
* Mon Apr  8 2019 ncutler@suse.com
- Version 2.8.dev.27+git.1554731117.4db414992:
  + FSAL_CEPH: don't abort the connection if we're deleting the export
    https://github.com/nfs-ganesha/nfs-ganesha/commit/0d62e92920730972351ab897e1ff2ed2f39fbf54
  + spec:
  * drop install command for ganesha-rados-grace as it is now installed by cmake
  * build: ganesha_nfsd as a DSO, i.e. libganesha_nfsd.so
  * build in UTF-8 environment
* Wed Feb 27 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Do a Release build to not include build host name (boo#1084909)
* Fri Feb 22 2019 ncutler@suse.com
- Version 2.8.dev.16+git.1550844464.79f319b6b:
  + spec, cmake: fix packaging of config_samples directory
* Fri Feb 15 2019 Jan Engelhardt <jengelh@inai.de>
- spec: update RPM groups and descriptions
* Thu Feb 14 2019 ncutler@suse.com
- spec:
  + drop with_systemd macro and rip out non-systemd conditional blocks
  + use %%_docdir instead of %%_defaultdocdir and list documentation files
    explicitly
  + stop building nfs-ganesha-utils (no longer needed; requires Python 2)
  + use "BuildRequires: distribution-release" to avoid exposure to
    rebuilds triggered by sles-release and openSUSE-release
    (credits to dimstar for this improvement)
  + drop "BuildRequires: systemd" for SUSE, since this is already
    covered by pkgconfig(systemd)
    (credits to dimstar for this improvement)
* Tue Feb 12 2019 ncutler@suse.com
- spec:
  + use less obnoxious "NFS-Ganesha" form of software name
  + use less acronyms in the descriptions (Reviewer note: the only FSALs
    actually built are the ones for Ceph (CephFS and RGW) and XFS, so we don't
    care about the others)
  + fix the Group lines
* Tue Feb 12 2019 rdias@suse.com
- Version 2.8.dev.16
  + spec: add liburcu-devel build dependency - from upstream commit message:
    cmake: always build in liburcu
    There is some infrastructure in liburcu for handling things locklessly
    that could be of great use to ganesha. That library is available on
    both Linux and FreeBSD, so there should be no reason we can't use it
    with ganesha.
    Change cmake to always search for liburcu and fail to configure if it
    isn't present.
* Tue Nov 20 2018 supriti.singh@suse.com
- Version 2.7.1
  + Spec file: fix ganesha-rados package installation
* Thu Nov 15 2018 supriti.singh@suse.com
- Version 2.7.1
  + Upgrade to ntirpc version 1.7.1
  + FSAL_CEPH: open file as root for COMMIT purposes
  + FSAL_CEPH: add an fallocate operation
  + FSAL_CEPH: enable the readdir_plus boolean
  + FSAL_CEPH: use ceph_ll_sync_inode to handle COMMIT call when available
  + FSAL_CEPH: abort the connection before shutdown if server will be restarting
  + FSAL_CEPH: rename onto non+empty directory should return NFS4ERR_EXIST
  + RADOS_URLS: enable them by default
  + RADOS_URLS: permit pool and object names containing '.'
  + FSAL_RGW:   support directory object as an export
  + Doc: Man page for ganesha+rados+tool and ganesha+cluster+design
  + CMake: Add support to build with libasan
  + specfile:  Allow packagers to remove dependency on rpcbind
  + specfile: move ganesha+raods+grace into a separate package
  + Async/vector API for read and write
  + Improvments in RecoveryBackend support
  + Code cleanup and refactoring
  + SAL: don't revoke delegations on export release
  + NLM_Share code fixes
  + gtest support
  + nfsd: handle rpcbind registration errors more gracefully
  + Avoid ABBA kind deadlock while IP release in grace period
  + Use temporary fd instead of global fd for getattr/setattr/LOCKT
  + Flex layout: Encode ff_layout4 and ff_device_addr4
  + ganesha_stats: event log for statistics activity
  + FSAL_MDCACHE: always lookup newname from uncached
  + Disallow client to create dirents with an empty name
  + Coverity fixes
  + Fix default config IPv6 connections
  + Log improvments
* Mon Apr 30 2018 supriti.singh@suse.com
- Version 2.6.1
  + Spec file: use ntirpc version 1.6.2
  + Avoid double free of subhandle in mdcache_new_entry
  + Reorder initialization sequence in nfs_Init
  + Updated man page for RADOS_KV
  + Fix fsid comparison to include fsid type
  + Better debug print for FSAL module refcounting
  + Don't double stack MDCACHE on FSAL_PSEUDO exports
  + Fix leakage in netconfig entities
  + Fix copyrights on FSAL_MEM
  + NFS: fix delegation conflict check to open4_ex
  + Fix dbus release
  + RADOS_KV: do copy in rados_kv_get before releasing read op
  + Libntirpc module: set the cmake module path correctly
  + Make code python2 and 3 compatiable
* Wed Jan 31 2018 supriti.singh@suse.com
- Version 2.6-rc4
  + Spec file: use %%_fillupdir macro
  + DRC code cleanup
  + NFSv3: Fix file descriptor leak
  + Fix log level for FSAL cookie
  + Fix new warning for gcc 7.2
  + ntirpc pullup
* Wed Jan 24 2018 astieger@suse.com
- drop rpmlintrc file, no longer required, bsc#997880
* Mon Dec 18 2017 supriti.singh@suse.com
- Version 2.6-dev22
  + Modularized recovery backend based on rados kv store
    + New config option "rados_kv"
  + NFSv4 delegation support
  + Explicitly mount specified bucket in librgw
  + New Reaper_Work_Per_Lane option
  + NFSv4: Allow '.' and '..' as target path in symlink creation
  + Fix root squashing for NFSv3
  + RADOS_URL: load nfs-ganesha config from generic URL
  + Stripped out FSAL ZFS
  + Allow configuration of NFSv4 minor versions
  + Ceph: wire up delegation requests and callbacks
  + Gtest for FSAL lookup latency microbenchmark
  + DBus interface to extract FSAL performance stats
  + DBUS interface for purging idmapper cache
  + Removal of support_ex
  + Use 'v6disabled' flag to know if IPv6 is disabled
  + FSAL_CEPH: no need to set credentials
* Sat Nov 25 2017 holgi@suse.com
- Add BuildRequires: libnsl-devel - bsc#1069819
* Fri Sep 15 2017 supriti.singh@suse.com
- Version 2.5.2.0
  + Add python-pyparsing for nfs-ganesha-utils
* Fri Sep  1 2017 ncutler@suse.com
- Version 2.5.2.0
  + update to upstream version 2.5.2
* Thu Aug  3 2017 supriti.singh@suse.com
- Version 2.5.1.1
  + Add license GPL-3.0+
  + bsc#997880:
    + DBus: allow root users only
  + rgw: implement compute_readdir_cookie and dirent_cmp
  + Fixes in hastable
  + MDCACHE: Fix rename/getattrs deadlock
  + Export: skip export entries that init_export_root fail
  + MDCACHE: Debug mdcache enabled by default
* Thu Jul  6 2017 supriti.singh@suse.com
- Version 2.5.025
  + RGW: Minor modification in config example and man page.
  + Fix closing at termination and non-supported services
  + MDCACHE: abort unlink on real error from the sub-FSAL.
  + MDCACHE: Don't update attributes when they're invalid
  + Let upcall events wait for initialization of general_fridge
  + Dirent/chunk LRU memory management
* Fri Jun 23 2017 supriti.singh@suse.com
- Version 2.5.024
  + Man page: Updated spec file for man page.
  + NFS4: Add result to OP tracepoint
  + bsc#102471:
    + ceph-common required by nfs-ganesha-ceph
    and nfs-ganesha-rgw
* Fri Jun  9 2017 supriti.singh@suse.com
- Version 2.5.023
- Upgrade to upstream version 2.5-final
- Parital fix bsc#1031444
  + Build with man page
- Enable nfs-ganesha-utils package build
- Disable gui_utils from nfs-ganesha-utils package
* Mon Jun  5 2017 ricardo.dias@suse.com
- Disabled gui_utils from nfs-ganesha-utils package
* Mon Jun  5 2017 ricardo.dias@suse.com
- Enabled nfs-ganesha-utils package build
* Tue May 23 2017 supriti.singh@suse.com
- Version 2.5.022
  + New config sample: rgw_bucket.conf
  + Logs are now stored at /var/log/ganesha/
  + Use "nfs-ganesha" instead of "ganesha" as
    service file.
* Thu Apr 27 2017 alekshmanan@suse.com
- Merge upstream v2.5-rc2
- nfs-ganesha.spec: don't build fsal_mem
* Thu Apr  6 2017 supriti.singh@suse.com
- Merge upstream V2.5-dev-20:
  + Add ganesha config editor
  + CMake: build against luminous librgw
- Fix bsc#1024711
  + config_samples: Fix unknown parameters
  + Use ceph.conf as default ganesha.conf
* Fri Jan 13 2017 supriti.singh@suse.com
- Merge upstream V2.5-dev-7
  + CephFS: add support to export subdirectories
  + CephFS: config option for user credentials
* Thu Nov 10 2016 ncutler@suse.com
- nfs-ganesha.spec: fix libntirpc.so version number
* Thu Nov 10 2016 ncutler@suse.com
- nfs-ganesha.spec: disable PANFS VSAL
* Thu Nov 10 2016 ncutler@suse.com
- nfs-ganesha.spec: backport upstream changes that occurred between
  V2.3 and V2.4.1
* Thu Nov 10 2016 ncutler@suse.com
- nfs-ganesha.spec: add ExclusiveArch for SLE and openSUSE, to match what we
  have in ceph.spec
* Thu Nov 10 2016 ncutler@suse.com
- Merge upstream V2.4.1
- CMakeLists.txt: handle openSUSE
* Wed Nov  9 2016 ncutler@suse.com
- Update to version 2.3.3+git.1478706663.6f1c7a4:
  + RGW: failing to bind to librados should be caught
* Mon Sep 12 2016 ncutler@suse.com
- Fix bsc#997879
  + nfs-ganesha.spec: fix license string/identifier
  + nfs-ganesha.spec: install and package LICENSE.txt
  + nfs-ganesha-rpmlintrc: drop setBadness('invalid-license', 0)
* Wed Sep  7 2016 ncutler@suse.com
- add standard copyright header to spec file
- Update to version 2.3.3+git.1472466979.bb9cf0a:
  + nfs: Use option grace_period to determine grace timeout
  + fsal_gluster: eliminate duplicate code in gluster2fsal_error()
  + FSAL_GLUSTER : adding logrotate file for ganesha-gfapi.log
  + [FSAL_GPFS] prevent negative values to be interpreted as read amount.
  + RPCSEC_GSS: When using kerberos validate principals but not handles
  + FSAL_GLUSTER: set default errno to EINVAL
  + Avoid setting socket max buffers
  + [nfs4_clientid.c] remove stale client_id reference from client_record
  + Handle clientid and client record decoupling in nfs_release_v4_client()
  + Stop MOUNT/NLM as additional services in NFSv4 only environments
  + [fridgethr.c] Prevent infinite loop for timed out sync.
  + FSAL_GLUSTER : symlink operation fails when acl is enabled
  + Remove duplicate definition of posix2fsal_attributes
  + NFSv3 SETATTR should NOT set ATTR_SPACEUSED when ATTR_SIZE is set
  + Add ATTR_FSID to NFS v3 attributes
  + [state_misc.c] Remove assert() for invalid owner type.
  + Explicitly set privilegedport to false in default PseudoFS export
  + FSAL_GLUSTER/Upcall: Change poll interval to 10us
  + Chomp tailing slash from pseudopath
  + Rescan /etc/mtab in GPFS and VFS FSALs one more time if
    claim_posix_filesystems fails. Added init_complete variable to avoid
    rescanning at start up time.
  + This patch is to fix the bug that changes the owner always to root when
    all_squash is turned on. The fix is to not change the owner if anon_uid
    is 0.
  + Clean up log setting functions
  + Add COMPONENT_TIRPC for tracing libntirpc
  + RGW: look for librgw.so in either lib or lib64
  + idmapping: add only_numeric_owners option (off by default)
  + Fix spurious compiler warning on some systems
  + rgw: add 3 new config options
  + Enables permission checks even when state is already present to prevent
    READ and WRITE operation using stolen stateid
  + find_package implementation for CEPH FSALs
  + Tweak FindCephFS.cmake and FindRGW.cmake
  + build: Fedora _hardened_build, fix compile errors
  + 32-bit: fix warnings/errors w/ old compilers, e.g. RHEL6 32-bit
  + Version V2.3.3
* Wed Aug  3 2016 ncutler@suse.com
- nfs-ganesha.spec: drop explicit ceph, rgw runtime dependencies
* Tue Aug  2 2016 ncutler@suse.com
- Update to version 2.3.2+git.1470139165.7aca631:
  + _service: migrate to SUSE/nfs-ganesha fork
  + regenerate tarball
* Tue Aug  2 2016 ncutler@suse.com
- nfs-ganesha-rpmlintrc:
  + fix conditional in %%post script
  + add Requires(post): procps for pgrep
* Tue Aug  2 2016 ncutler@suse.com
- nfs-ganesha-rpmlintrc: disable invalid-license badness just to get
  a testing build in IBS
* Tue Aug  2 2016 ncutler@suse.com
- nfs-ganesha.spec: move ntirpc headers to a separate devel package
* Tue Aug  2 2016 ncutler@suse.com
- nfs-ganesha-rpmlintrc: new file (to reduce badness)
- nfs-ganesha.spec: refrain from packaging /var/run/ganesha (and
  cut badness by another 10000)
* Tue Aug  2 2016 ncutler@suse.com
- nfs-ganesha.spec: install sysconfig using %%fillup_only (thereby
  reducing RPMLINT badness by 10000)
* Tue Aug  2 2016 ncutler@suse.com
- nfs-ganesha.spec: make %%post script idempotent (check for
  dbus-daemon processes before running killall on them)
* Tue Aug  2 2016 ncutler@suse.com
- nfs-ganesha.spec:
  + install systemd service files with 444 permissions
  + add %%pre scriptlet to fix %%post failure in OBS
    /usr/sbin/systemd-sysv-convert: line 62:
    /var/lib/systemd/sysv-convert/database: No such file or directory
* Tue Aug  2 2016 ncutler@suse.com
- nfs-ganesha.spec: Requires(post): psmisc for killall
* Tue Aug  2 2016 ncutler@suse.com
- nfs-ganesha.spec:
  + fix systemd-related build and runtime dependencies
  + make /usr/lib64/ganesha be owned by a package
* Tue Aug  2 2016 ncutler@suse.com
- Update to version 2.3.2+git.1470139165.7aca631:
  + Revert "CMakeLists.txt: source /etc/os-release to get NAME"
  + CMakeLists.txt: source /etc/os-release to get NAME
  + CMakeLists.txt: handle openSUSE
- _service: build from smithfarm/nfs-ganesha fork (ses4 branch)
- nfs-ganesha.spec:
  + BuildRequires: openSUSE-release on openSUSE, sles-release on SLES
  + enable ceph, rgw build
  + use libcephfs-devel instead of deprecated ceph-devel
  + use librgw-devel instead of deprecated rgw-devel
  + install documentation properly
* Tue Aug  2 2016 ncutler@suse.com
- nfs-ganesha.spec: enable ceph, RGW build
- nfs-ganesha.spec: create and package a documentation directory
* Tue Aug  2 2016 ncutler@suse.com
- nfs-ganesha.spec: hack to get build to start
- _service: hack to get build to start
* Tue Aug  2 2016 ncutler@suse.com
- Initial submission based on upstream V2.3.2 tag
